@@ -1983,7 +1983,7 @@ class SArray(object):
     def show(self, view=None):
         """
         show(view=None)
-        Visualize the SArray with GraphLab Canvas. This function starts Canvas
+        Visualize the SArray with GraphLab :mod:`~graphlab.canvas`. This function starts Canvas
         if it is not already running. If the SArray has already been plotted,
         this function will update the plot.
 
