@@ -325,25 +325,9 @@ class Ec2PredictiveServiceEnvironment(PredictiveServiceEnvironment):
             # Create the load balancer.
             _logger.info("[Step 2/5]: Launching Load Balancer.")
 
-            # Look our security group id
-            security_group = None
-            while ((datetime.now() - started).total_seconds() < MAX_CREATE_TIMEOUT_SECS):
-                ec2_conn = boto.ec2.connect_to_region(ec2_config.region, **aws_credentials)
-                for sg in ec2_conn.get_all_security_groups():
-                    if(GRAPHLAB_NAME == sg.name):
-                        security_group = sg
-                        break   # found it
-                if security_group:
-                    break # no more eventual consistency
-                else:
-                    sleep(1)
-            else:
-                raise RuntimeError("Unable to find expected security group needed to configure load balancer.")
-
             while ((datetime.now() - started).total_seconds() < MAX_CREATE_TIMEOUT_SECS):
                 try:
-                    lb = conn.create_load_balancer(name, zones, [listener_tuple],
-                                                   security_groups = [security_group.id])
+                    lb = conn.create_load_balancer(name, zones, [listener_tuple])
                     break
                 except BotoServerError as e:
                     # We just uploaded the certificate, so there's a good chance it will not be found, yet.
@@ -353,6 +337,25 @@ class Ec2PredictiveServiceEnvironment(PredictiveServiceEnvironment):
             else:
                 raise RuntimeError("Unable to successfully create load balancer. Please confirm in AWS Management Console")
 
+
+            # If we're running in a VPC (i.e. not "EC2-Classic") we need to attach a security group.
+            if ec2_hosts[0].instance.vpc_id:
+                # Look up security group id
+                security_group = None
+                while ((datetime.now() - started).total_seconds() < MAX_CREATE_TIMEOUT_SECS):
+                    ec2_conn = boto.ec2.connect_to_region(ec2_config.region, **aws_credentials)
+                    for sg in ec2_conn.get_all_security_groups():
+                        if(GRAPHLAB_NAME == sg.name):
+                            security_group = sg
+                            break   # found it
+                    if security_group:
+                        break # no more eventual consistency
+                    else:
+                        sleep(1)
+                else:
+                    raise RuntimeError("Unable to find expected security group needed to configure load balancer.")
+                lb.apply_security_groups([sg.id])
+
             _logger.info("[Step 3/5]: Configuring Load Balancer.")
 
             # Configure healthCheck
