@@ -512,10 +512,10 @@ def create(dataset, target,
 
       >>> url = 'http://s3.amazonaws.com/gl-testdata/xgboost/mushroom.csv'
       >>> data = graphlab.SFrame.read_csv(url)
-      >>> data['target'] = (data['target'] == 'e')
+      >>> data['label'] = (data['label'] == 'p')
       
       >>> train, test = data.random_split(0.8)
-      >>> model = graphlab.boosted_trees.create(train, target='label')
+      >>> model = graphlab.boosted_trees_classifier.create(train, target='label')
       
       >>> predicitons = model.classify(test)
       >>> results = model.evaluate(test)
