@@ -1,11 +1,12 @@
+import graphlab.connect as _mt
 from graphlab.data_structures.sgraph import SGraph as _SGraph
-import graphlab.toolkits.main as _main
-from graphlab.toolkits.graph_analytics.model_base import GraphAnalyticsModel as _ModelBase
-import copy
+import graphlab.toolkits._main as _main
+from graphlab.toolkits.graph_analytics._model_base import GraphAnalyticsModel as _ModelBase
+import copy as _copy
 
 _HAS_IPYTHON = True
 try:
-    import IPython.core.display
+    import IPython.core.display as _IPython
 except:
     _HAS_IPYTHON = False
 
@@ -18,10 +19,16 @@ def get_default_options():
     -------
     out : dict
 
+    See Also
+    --------
+    ShortestPathModel.get_current_options
+    
     Examples
     --------
     >>> graphlab.shortest_path.get_default_options()
     """
+    _mt._get_metric_tracker().track('toolkit.graph_analytics.sssp.get_default_options')
+
     return _main.run('sssp_default_options', {})
 
 
@@ -39,13 +46,17 @@ class ShortestPathModel(_ModelBase):
     +----------------+------------------------------------------------------------+
     | Field          | Description                                                |
     +================+============================================================+
-    | graph          | A new SGraph with the triangle count as a vertex property. |
+    | graph          | A new SGraph with the distance as a vertex property        |
     +----------------+------------------------------------------------------------+
-    | num_triangles  | Total number of triangles in the graph.                    |
+    | distance       | An SFrame with each vertex's distance to the source vertex |
     +----------------+------------------------------------------------------------+
-    | triangle_count | An SFrame with the triangle count for each vertex.         |
+    | weight_field   | The edge field for weight                                  |
     +----------------+------------------------------------------------------------+
-    | runtime        | Total runtime of the toolkit                               |
+    | source_vid     | The source vertex id                                       |
+    +----------------+------------------------------------------------------------+
+    | max_distance   | Maximum distance between any two vertices                  |
+    +----------------+------------------------------------------------------------+
+    | training_time  | Total training time of the model                           |
     +----------------+------------------------------------------------------------+
 
     An instance of this model can be created using
@@ -158,10 +169,10 @@ class ShortestPathModel(_ModelBase):
                 path_names = set([x[0] for x in path])
                 path_highlight = list(set.intersection(path_names, set(highlight)))
 
-                plot = sub_g.show(vlabel='id', highlight=path_highlight, **kwargs)
-                if _HAS_IPYTHON:
-                    IPython.core.display.display(plot)
-
+            plot = sub_g.show(vlabel='id', highlight=path_highlight, **kwargs)
+            if _HAS_IPYTHON:   
+                _IPython.display(plot)
+      
         return path
 
     def _generate_path_sframe(self):
@@ -172,8 +183,8 @@ class ShortestPathModel(_ModelBase):
         source_vid = self['source_vid']
         weight_field = self['weight_field']
 
-        query_table = copy.copy(self.get('distance'))
-        query_table.add_row_number('row_id')
+        query_table = _copy.copy(self.get('distance'))
+        query_table = query_table.add_row_number('row_id')
 
         g = self.get('graph').add_vertices(query_table)
         # The sequence id which a vertex is visited, initialized with 0 meaning not visited.
@@ -191,13 +202,18 @@ class ShortestPathModel(_ModelBase):
                 dst['__parent__'] = max(dst['__parent__'], src['row_id'])
             return (src, edge, dst)
 
+        # the internal lambda appear to have some issues. 
+        # traverse_fun = lambda src, edge, dst:  \
+        #     gl.extensions._toolkits.graph.sssp.shortest_path_traverse_function(src, edge, dst, 
+        #             source_vid, weight_field)
+
         g = g.triple_apply(traverse_fun, ['__parent__'])
         query_table = query_table.join(g.get_vertices()[['__id', '__parent__']], '__id').sort('row_id')
         query_table.rename({'__parent__': 'parent_row_id', '__id': 'vid'})
         return query_table
 
 
-def create(graph, source_vid, weight_field="", max_distance=1e30, verbose=True, plot=False):
+def create(graph, source_vid, weight_field="", max_distance=1e30, verbose=True):
     """
     Compute the single source shortest path distance from the source vertex to
     all vertices in the graph. Note that because SGraph is directed, shortest
@@ -220,9 +236,6 @@ def create(graph, source_vid, weight_field="", max_distance=1e30, verbose=True,
     verbose : bool, optional
         If True, print progress updates.
 
-    plot : bool, optional
-        If True, display the progress plot.
-
     Returns
     -------
     out : ShortestPathModel
@@ -259,13 +272,73 @@ def create(graph, source_vid, weight_field="", max_distance=1e30, verbose=True,
     --------
     ShortestPathModel
     """
+    _mt._get_metric_tracker().track('toolkit.graph_analytics.sssp.create')
+
     if not isinstance(graph, _SGraph):
         raise TypeError('graph input must be a SGraph object.')
 
-    if plot is True:
-        print "The plot functionality for shortest path is not yet implemented."
-
     opts = {'source_vid': source_vid, 'weight_field': weight_field,
             'max_distance': max_distance, 'graph': graph.__proxy__}
-    params = _main.run('sssp', opts, verbose, plot)
+    params = _main.run('sssp', opts, verbose)
     return ShortestPathModel(params['model'])
+
+
+def _compute_shortest_path(graph, source_vids, dest_vids, weight_field=""):
+    """
+    Computes shortest paths from any vertex in source_vids to any vertex
+    in dest_vids.  Note that because SGraph is directed, shortest paths are
+    also directed. To find undirected shortes paths add edges to the SGraph in
+    both directions. Returns a list of shortest paths between source_vids 
+    and dest_vids.
+
+    Note that this function does not compute all shortest paths between every 
+    (source, dest) pair. It computes 
+
+    Parameters
+    ----------
+    graph : SGraph
+        The graph on which to compute shortest paths.
+
+    source_vids : vertex ID or list of vertex IDs
+        ID of the source vertices
+
+    dest_vids : vertex ID or list of vertex IDs
+        ID of the destination vertices
+
+    weight_field : str, optional.
+        The edge field representing the edge weights. If empty, uses unit
+        weights.
+
+    Returns
+    -------
+    out :  An SArray of lists of all the same length. 
+        Each list describes a path of vertices leading from one source
+        vertex to one destination vertex.
+
+    References
+    ----------
+    - `Wikipedia - ShortestPath <http://en.wikipedia.org/wiki/Shortest_path_problem>`_
+
+    Examples
+    --------
+    If given an :class:`~graphlab.SGraph` ``g``, we can create
+    a :class:`~graphlab.shortest_path.ShortestPathModel` as follows:
+
+    >>> edge_src_ids = ['src1', 'src2',   'a', 'b', 'c'  ]
+    >>> edge_dst_ids = [   'a',    'b', 'dst', 'c', 'dst']
+    >>> edges = graphlab.SFrame({'__src_id': edge_src_ids, '__dst_id': edge_dst_ids})
+    >>> g=gl.SGraph().add_edges(edges)
+    >>> graphlab.shortest_path.compute_shortest_path(g, ["src1","src2"], "dst")
+    [['a','dst']]
+
+    See Also
+    --------
+    ShortestPathModel
+    """
+    _mt._get_metric_tracker().track('toolkit.graph_analytics.shortest_path.get_shortest_path')
+    if type(source_vids) != list:
+        source_vids = [source_vids]
+    if type(dest_vids) != list:
+        dest_vids = [dest_vids]
+    import graphlab
+    return graphlab.SArray(graphlab.extensions._toolkits.graph.sssp.all_shortest_paths(graph, source_vids, dest_vids, weight_field))
